@@ -470,7 +470,8 @@ class VariableClUpdateSyncOverlayRep(ReadonlyVariable):
     type = "list"
 
     def get(self):
-        return filter(lambda x: x != "portage", self.Get('cl_update_sync_rep'))
+        return filter(lambda x: x not in ("portage", "gentoo"),
+               self.Get('cl_update_sync_rep'))
 
 
 class VariableClUpdateOutdateSet(ReadonlyVariable):
